#
# Conditional build:
%bcond_without	doc	# HTML documentation
%bcond_without	python2 # CPython 2.x module
%bcond_without	python3 # CPython 3.x module
%bcond_without	tests	# unit tests

Summary:	A pure Python library for multiprecision floating-point arithmetic
Summary(pl.UTF-8):	Czysto pythonowa biblioteka do arytmetyki zmiennoprzecinkowej wielokrotnej precyzji
Name:		python-mpmath
Version:	1.2.1
Release:	1
License:	BSD
Group:		Libraries/Python
# pypi release is missing docs
Source0:	https://files.pythonhosted.org/packages/source/m/mpmath/mpmath-%{version}.tar.gz
# Source0-md5:	ef8a6449851755319673b06f71731d52
# ... so use github
#Source0Download: https://github.com/fredrik-johansson/mpmath/releases
#Source0:	https://github.com/fredrik-johansson/mpmath/archive/%{version}/mpmath-%{version}.tar.gz
## Source0-md5:	c06bdf456bbbf092c929931974c8dac9
URL:		http://mpmath.org/
%if %{with python2}
BuildRequires:	python-devel >= 1:2.7
BuildRequires:	python-setuptools >= 1:36.7.0
BuildRequires:	python-setuptools_scm >= 1.7.0
%if %{with tests}
BuildRequires:	python-pytest >= 4.6
%endif
%endif
%if %{with python3}
BuildRequires:	python3-devel >= 1:3.4
BuildRequires:	python3-setuptools >= 1:36.7.0
BuildRequires:	python3-setuptools_scm >= 1.7.0
%if %{with tests}
BuildRequires:	python3-pytest >= 4.6
%endif
%endif
BuildRequires:	rpmbuild(macros) >= 1.714
%{?with_doc:BuildRequires:	sphinx-pdg}
BuildArch:	noarch
BuildRoot:	%{tmpdir}/%{name}-%{version}-root-%(id -u -n)

%description
Mpmath is a pure-Python library for multiprecision floating-point
arithmetic. It provides an extensive set of transcendental functions,
unlimited exponent sizes, complex numbers, interval arithmetic,
numerical integration and differentiation, root-finding, linear
algebra, and much more. Almost any calculation can be performed just
as well at 10-digit or 1000-digit precision, and in many cases mpmath
implements asymptotically fast algorithms that scale well for
extremely high precision work. If available, mpmath will (optionally)
use gmpy to speed up high precision operations.

If you require plotting capabilities in mpmath, install
python-matplotlib.

%description -l pl.UTF-8
Mpmath to czysto pythonowa biblioteka do arytmetyki
zmiennoprzecinkowej wielokrotnej precyzji. Zapewnia obszerny zbiór
funkcji przestępnych, nieograniczone rozmiary wykładnika, liczby
zespolone, arytmetykę na przedziałach, całkowanie i różniczkowanie
numeryczne, szukanie pierwiastków, algebrę liniową itd. Można
wykonać prawie dowolne obliczenia, zarówno z 10-cyfrową, jak i
1000-cyfrową dokładnością, a dla wielu przypadków mpmath ma
zaimplementowane asymptotycznie szybkie algorytmy, dobrze skalujące
się dla bardzo dużej precyzji. Mpmath może opcjonalnie (jeśli jest
dostępny) używać modułu gmpy do przyspieszenia operacji.

Do obsługi wykresów w mpmath należy zainstalować pakiet
python-matplotlib.

%package -n python3-mpmath
Summary:	A pure Python library for multiprecision floating-point arithmetic
Summary(pl.UTF-8):	Czysto pythonowa biblioteka do arytmetyki zmiennoprzecinkowej wielokrotnej precyzji
Group:		Libraries/Python

%description -n python3-mpmath
Mpmath is a pure-Python library for multiprecision floating-point
arithmetic. It provides an extensive set of transcendental functions,
unlimited exponent sizes, complex numbers, interval arithmetic,
numerical integration and differentiation, root-finding, linear
algebra, and much more. Almost any calculation can be performed just
as well at 10-digit or 1000-digit precision, and in many cases mpmath
implements asymptotically fast algorithms that scale well for
extremely high precision work. If available, mpmath will (optionally)
use gmpy to speed up high precision operations.

If you require plotting capabilities in mpmath, install
python3-matplotlib.

%description -n python3-mpmath -l pl.UTF-8
Mpmath to czysto pythonowa biblioteka do arytmetyki
zmiennoprzecinkowej wielokrotnej precyzji. Zapewnia obszerny zbiór
funkcji przestępnych, nieograniczone rozmiary wykładnika, liczby
zespolone, arytmetykę na przedziałach, całkowanie i różniczkowanie
numeryczne, szukanie pierwiastków, algebrę liniową itd. Można
wykonać prawie dowolne obliczenia, zarówno z 10-cyfrową, jak i
1000-cyfrową dokładnością, a dla wielu przypadków mpmath ma
zaimplementowane asymptotycznie szybkie algorytmy, dobrze skalujące
się dla bardzo dużej precyzji. Mpmath może opcjonalnie (jeśli jest
dostępny) używać modułu gmpy do przyspieszenia operacji.

Do obsługi wykresów w mpmath należy zainstalować pakiet
python3-matplotlib.

%package doc
Summary:	API documentation for mpmath module
Summary(pl.UTF-8):	Dokumentacja API modułu mpmath
Group:		Documentation
Requires:	%{name} = %{version}-%{release}

%description doc
This package contains the HTML documentation for mpmath module.

%description doc -l pl.UTF-8
Ten pakiet zawiera dokumentację modułu mpmath w formacie HTML.

%prep
%setup -q -n mpmath-%{version}

shebangs="mpmath/matrices/eigen.py mpmath/matrices/eigen_symmetric.py mpmath/tests/test_eigen.py mpmath/tests/test_eigen_symmetric.py mpmath/tests/test_levin.py"
# Get rid of unnecessary shebangs
for lib in $shebangs; do
	%{__sed} '/^#!.*/d; 1q' $lib > $lib.new && \
		touch -r $lib $lib.new && \
		%{__mv} $lib.new $lib
done

%build
%if %{with python2}
%py_build

%if %{with tests}
# test_axes uses DISPLAY
#%{__python} -m pytest -k 'not test_axes' mpmath/tests
PYTEST_DISABLE_PLUGIN_AUTOLOAD=1 \
%{__python} -m pytest -k 'not test_axes' mpmath/tests
%endif
%endif

%if %{with python3}
%py3_build

%if %{with tests}
#%{__python3} -m pytest -k 'not test_axes' mpmath/tests
PYTEST_DISABLE_PLUGIN_AUTOLOAD=1 \
%{__python3} -m pytest -k 'not test_axes' mpmath/tests
%endif
%endif

%if %{with doc}
cd doc
install -d build
sphinx-build -E source build
%endif

%install
rm -rf $RPM_BUILD_ROOT

%if %{with python2}
%py_install

%py_postclean
%{__rm} -r $RPM_BUILD_ROOT%{py_sitescriptdir}/mpmath/tests
%endif

%if %{with python3}
%py3_install

%{__rm} -r $RPM_BUILD_ROOT%{py3_sitescriptdir}/mpmath/tests
%endif

%clean
rm -rf $RPM_BUILD_ROOT

%if %{with python2}
%files
%defattr(644,root,root,755)
%doc CHANGES LICENSE README.rst TODO
%{py_sitescriptdir}/mpmath
%{py_sitescriptdir}/mpmath-%{version}-*.egg-info
%endif

%if %{with python3}
%files -n python3-mpmath
%defattr(644,root,root,755)
%doc CHANGES LICENSE README.rst TODO
%{py3_sitescriptdir}/mpmath
%{py3_sitescriptdir}/mpmath-%{version}-*.egg-info
%endif

%if %{with doc}
%files doc
%defattr(644,root,root,755)
%doc doc/build/{_images,_static,calculus,functions,*.html,*.js}
%endif
%changelog
* Sun Jan 08 2023 PLD Linux Team <feedback@pld-linux.org>
- For complete changelog see: http://git.pld-linux.org/?p=packages/python-mpmath.git;a=log;h=master

* Sun Jan 08 2023 Jakub Bogusz <qboosh@pld-linux.org> eb601ab
- updated to 1.2.1

* Wed Mar 30 2022 Jan Rękorajski <baggins@pld-linux.org> 70c5971
- rebuild with tests and docs

* Sat Mar 26 2022 Jan Rękorajski <baggins@pld-linux.org> f4f8e97
- rebuild with python 3.10

* Fri Mar 25 2022 Jan Rękorajski <baggins@pld-linux.org> afb148c
- rebuild with python 3.10

* Thu Dec 16 2021 Jakub Bogusz <qboosh@pld-linux.org> ffe7e8a
- setuptools epoch

* Sat Feb 27 2021 Jan Rękorajski <baggins@pld-linux.org> fae38cf
- release 4 (by relup.sh)

* Mon Oct 28 2019 Jan Rękorajski <baggins@pld-linux.org> ebb5a72
- rebuild with python 3.8
- release 3 (by relup.sh)

* Thu Sep 12 2019 Jakub Bogusz <qboosh@pld-linux.org> d610cd4
- don't package tests; release 2

* Wed Sep 11 2019 Jakub Bogusz <qboosh@pld-linux.org> d10c286
- updated to 1.1.0, added tests

* Mon Jul 02 2018 Arkadiusz Miśkiewicz <arekm@maven.pl> 552d420
- release 3 (by relup.sh)

* Thu Dec 29 2016 Arkadiusz Miśkiewicz <arekm@maven.pl> cf2e7c7
- python 3.6
- release 2 (by relup.sh)

* Sun May 15 2016 Jan Rękorajski <baggins@pld-linux.org> 3b6ceee
- up to 0.19

* Sun May 15 2016 Jan Rękorajski <baggins@pld-linux.org> 35871d7
- release 6 (by relup.sh)

* Sun Nov 29 2015 Jacek Konieczny <jajcus@jajcus.net> 485dc50
- BR: rpmbuild(macros) >= 1.710

* Sat Nov 28 2015 Jacek Konieczny <jajcus@jajcus.net> 43af571
- release 5 (by relup.sh)

* Sat Nov 28 2015 Jacek Konieczny <jajcus@jajcus.net> 1355b8a
- automatic change: use py_build/py_install macros

* Mon Sep 14 2015 Arkadiusz Miśkiewicz <arekm@maven.pl> 7c92d2d
- release 4 (by relup.sh)

* Sun Sep 13 2015 Arkadiusz Miśkiewicz <arekm@maven.pl> ad61d6f
- python 3.5 rebuild
- release 3 (by relup.sh)

* Sun Oct 19 2014 Arkadiusz Miśkiewicz <arekm@maven.pl> 15e239f
- python 3.4
- release 2 (by relup.sh)

* Tue Feb 25 2014 Jan Rękorajski <baggins@pld-linux.org> 07be5a7
- new, based on fedora

